@@ -3,6 +3,7 @@ from zlib import compress, decompress
 from base64 import b64encode, b64decode
 from inspect import getsource
 from tempfile import gettempdir
+import metamake
 from metamake._path import path, path
 
 def serialize_metamake_to_makefile(makefile_filename):
@@ -16,6 +17,19 @@ def serialize_metamake_to_makefile(makefile_filename):
         old_makefile_file = open(makefile_filename, "r")
         try:
             old_makefile_file_contents = old_makefile_file.read()
+            
+            # check the version, don't clobber newer metamake versions
+            try:
+                version_line = old_makefile_file_contents.split("\n")[0]
+                if "metamake" in version_line:
+                    old_makefile_metamake_version = version_line[11:].strip()
+                    if old_makefile_metamake_version > metamake.__version__:
+                        # skip this bootstrapping altogether when this version is older
+                        return
+            except:
+                # something was wrong with the version number, assume it is out of date
+                pass
+            
         finally:
             old_makefile_file.close()
     else:
@@ -24,6 +38,9 @@ def serialize_metamake_to_makefile(makefile_filename):
     # open the makefile file for writing the serialized code
     new_makefile_file = open(makefile_filename, "w")
     
+    # write the version number
+    new_makefile_file.write("# metamake %s\n" % metamake.__version__)
+    
     try:
         
         # get the metamake module directory
@@ -113,7 +130,7 @@ def standalone_deserialize_metamake_from_makefile(makefile_filename):
     makefile_file = open(makefile_filename)
     makefile_lines = []
     try:
-        makefile_lines = [line.replace("# ","") for line in makefile_file.readlines() if line.startswith("#")]
+        makefile_lines = [line.replace("# ","") for line in makefile_file.readlines() if line.startswith("#") and not line.startswith("# metamake")]
     finally:
         makefile_file.close()
     
